# BinanceAsyncWebsocket

Binance asynchronous websocket SDK. For now it could watch only some kind of information of user data.

This module is mainly classes inherited from
module ['AsyncWebsocketStreamInterface'](https://pypi.org/project/AsyncWebsocketStreamInterface/). For the usage detail,
refer to that module.